<?php // phpcs:ignore WordPress.Files.FileName.InvalidClassFileName
require_once __DIR__ . '/tiled-gallery-square.php';

/**
 * Jetpack tiled gallery layout circle class.
 */
class Jetpack_Tiled_Gallery_Layout_Circle extends Jetpack_Tiled_Gallery_Layout_Square {
	/**
	 * Type of tiled gallery.
	 *
	 * @var string
	 */
	protected $type = 'circle';
}
